package com.sf.web.dms.fes.control;

package ..deTemp.1731158773481;

import com.sf.web.dms.fes.bean.FesBean;
import com.sf.web.dms.fes.bean.FesChanBean;
import com.sf.web.dms.fes.bean.FesQueryParaVO;
import com.sf.web.dms.fes.bean.RtuBean;
import com.sf.web.dms.fes.bean.RtuPmsBean;
import com.sf.web.dms.fes.bean.RtuPmsParaVo;
import com.sf.web.dms.fes.entity.FesGroup;
import com.sf.web.dms.fes.service.FesMngService;
import com.smartframework.core.annotation.SmartComment;
import com.smartframework.core.dao.page.PagingBean;
import com.smartframework.core.i18n.I18n;
import com.smartframework.core.smart.SmartView;
import com.smartframework.web.core.Constants;
import com.smartframework.web.core.bean.HeaderConfig;
import com.smartframework.web.core.control.BasicControl;
import com.smartframework.web.core.queryfilter.QueryFilter;
import com.smartframework.web.core.util.DateUtil;
import com.smartframework.web.core.util.ExcelDataUtil;
import com.smartframework.web.core.util.ParameterUtils;
import java.io.BufferedInputStream;
import java.io.BufferedReader;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import net.sf.json.JSONArray;
import net.sf.json.JSONObject;
import org.apache.log4j.Logger;
import org.ini4j.Profile;
import org.ini4j.Wini;
import org.springframework.util.FileCopyUtils;

public class FesMngControl extends BasicControl {
  private static final char[] DIGITS_LOWER = new char[] { 
      '0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 
      'a', 'b', 'c', 'd', 'e', 'f' };
  
  private static final char[] DIGITS_UPPER = new char[] { 
      '0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 
      'A', 'B', 'C', 'D', 'E', 'F' };
  
  static Logger logger = Logger.getLogger(com.sf.web.dms.fes.control.FesMngControl.class);
  
  String WAVE_FILE_LOCATION = Constants.getString("dms.rtu.pms.files.folder", "D:/upload");
  
  private FesMngService fesMngService;
  
  public FesMngService getFesMngService() {
    return this.fesMngService;
  }
  
  public void setFesMngService(FesMngService fesMngService) {
    this.fesMngService = fesMngService;
  }
  
  @SmartComment("解析ini文件")
  public SmartView analysisIni(File file) {
    if (file == null) {
      logger.debug("上传文件为空");
      return SmartView.ERROR("上传文件为空");
    } 
    try {
      Wini ini = new Wini(new File(file.getPath()));
      Profile.Section sectionKey = (Profile.Section)ini.get("PARA_KEY");
      Profile.Section sectionName = (Profile.Section)ini.get("PARA_NAME");
      Profile.Section sectionDet = (Profile.Section)ini.get("PARA_VALUE_DEFAULT");
      Profile.Section sectionDesc = (Profile.Section)ini.get("PARA_DESCRIPTION");
      if (ParameterUtils.isEmptyOrNull(sectionKey))
        return SmartView.ERROR("ini文件编码格式应为UTF-8"); 
      return SmartView.SUCCESS(this.fesMngService.saveFesChanpara(sectionKey, sectionName, sectionDet, sectionDesc, file.getName(), file));
    } catch (IOException e) {
      e.printStackTrace();
      return SmartView.ERROR("解析文件错误");
    } 
  }
  
  @SmartComment("查询fes-app")
  public SmartView queryFesApp() {
    return SmartView.SUCCESS(this.fesMngService.queryFesApp());
  }
  
  @SmartComment("懒加载树")
  public SmartView queryFesData(String pid, Integer level) {
    if (ParameterUtils.isEmptyOrNull(pid)) {
      logger.debug("数据异常");
      return SmartView.ERROR("pid不能为空");
    } 
    if (ParameterUtils.isEmptyOrNull(level)) {
      logger.debug("数据异常");
      return SmartView.ERROR("节点信息不能为空");
    } 
    return SmartView.SUCCESS(this.fesMngService.queryFesData(pid, level));
  }
  
  @SmartComment("构建左侧树")
  public SmartView treeData() {
    return SmartView.SUCCESS(this.fesMngService.treeData());
  }
  
  @SmartComment("刷新右侧通道表格")
  public SmartView refrashChanData(String groupId, String chanName, Integer pageSize, Integer pageIndex) {
    return pageView(this.fesMngService.reFrashChanData(groupId, chanName, pageSize, pageIndex));
  }
  
  @SmartComment("刷新右侧RTU表格")
  public SmartView refrashRtuData(String groupId, String rtuName, Integer pageSize, Integer pageIndex) {
    return pageView(this.fesMngService.reFrashRtuData(groupId, rtuName, pageSize, pageIndex));
  }
  
  @SmartComment("记录所属域")
  public SmartView queryDomain() {
    return SmartView.SUCCESS(this.fesMngService.queryDomain());
  }
  
  @SmartComment("组类型")
  public SmartView queryGroupType() {
    return SmartView.SUCCESS(this.fesMngService.queryGroupType());
  }
  
  @SmartComment("点号类型")
  public SmartView queryPointType() {
    return SmartView.SUCCESS(this.fesMngService.queryPointType());
  }
  
  @SmartComment("是否停用")
  public SmartView queryIsUsed() {
    return SmartView.SUCCESS(this.fesMngService.queryIsUsed());
  }
  
  @SmartComment("通讯方式")
  public SmartView queryComm() {
    return SmartView.SUCCESS(this.fesMngService.queryComm());
  }
  
  @SmartComment("采集协议")
  public SmartView queryProto() {
    return SmartView.SUCCESS(this.fesMngService.queryProto());
  }
  
  @SmartComment("前置机组")
  public SmartView queryNodeGroup() {
    return SmartView.SUCCESS(this.fesMngService.queryNodeGroup());
  }
  
  @SmartComment("系统标识")
  public SmartView querySysId() {
    return SmartView.SUCCESS(this.fesMngService.querySysId());
  }
  
  @SmartComment("规约组")
  public SmartView saveAndUpdate(FesGroup fesGroup) {
    if (ParameterUtils.isEmptyOrNull(fesGroup)) {
      logger.debug("规约组信息为空");
      return SmartView.ERROR("规约组信息为空");
    } 
    return SmartView.SUCCESS(this.fesMngService.saveOrUpdate(fesGroup));
  }
  
  @SmartComment("查询规约组信息")
  public SmartView queryGroupInfo(Integer id) {
    if (ParameterUtils.isEmptyOrNull(id)) {
      logger.info("规约组id为空");
      return SmartView.ERROR("规约组id为空");
    } 
    return SmartView.SUCCESS(this.fesMngService.queryGroupInfo(id));
  }
  
  @SmartComment("删除规约组")
  public SmartView deleteGroupInfo(Integer id) {
    if (ParameterUtils.isEmptyOrNull(id)) {
      logger.info("规约组id为空");
      return SmartView.ERROR("规约组id为空");
    } 
    return SmartView.SUCCESS(this.fesMngService.deleteGroupInfo(id));
  }
  
  @SmartComment("列出所有规约组")
  public SmartView listGroup() {
    return SmartView.SUCCESS(this.fesMngService.listGroupInfo());
  }
  
  @SmartComment("容器表")
  public SmartView listContainerTable() {
    return SmartView.SUCCESS(this.fesMngService.listContainerTable());
  }
  
  @SmartComment("容器id")
  public SmartView listContainerId(FesQueryParaVO queryPara) {
    if (ParameterUtils.isEmptyOrNull(queryPara.getContainerTablename())) {
      logger.info("容器表名不能为空");
      return SmartView.ERROR("容器表名不能为空");
    } 
    return pageView(this.fesMngService.listContainerId(queryPara));
  }
  
  @SmartComment("通道扩展参数")
  public SmartView listChanExtend(Integer groupId) {
    return SmartView.SUCCESS(this.fesMngService.listChanExtend(groupId));
  }
  
  @SmartComment("规约扩展参数")
  public SmartView listGroupExtend(Integer groupId) {
    return SmartView.SUCCESS(this.fesMngService.listGroupExtend(groupId));
  }
  
  @SmartComment("保存通道参数")
  public SmartView saveFesChan(Integer groupId, FesChanBean fesChan, List<FesBean> extendChanData, List<FesBean> extendGroupData, String keyPath, Boolean isNewFile) {
    if (ParameterUtils.isEmptyOrNull(fesChan))
      return SmartView.ERROR("通道参数为空"); 
    if (ParameterUtils.isEmptyOrNull(extendChanData))
      return SmartView.ERROR("通道扩展参数为空"); 
    if (ParameterUtils.isEmptyOrNull(extendGroupData))
      return SmartView.ERROR("规约扩展参数为空"); 
    return dbAccess(this.fesMngService.saveFesChan(groupId, fesChan, extendChanData, extendGroupData, keyPath, isNewFile));
  }
  
  @SmartComment("规约参数")
  public SmartView listGroupInfoById(Integer groupId) {
    return SmartView.SUCCESS(this.fesMngService.listGroupInfoById(groupId));
  }
  
  @SmartComment("通道参数")
  public SmartView listChanInfoById(Integer chanId) {
    return SmartView.SUCCESS(this.fesMngService.listChanInfoById(chanId));
  }
  
  @SmartComment("终端类型")
  public SmartView loadRtutype() {
    return SmartView.SUCCESS(this.fesMngService.loadRtuType());
  }
  
  @SmartComment("生命周期")
  public SmartView loadRtuLife() {
    return SmartView.SUCCESS(this.fesMngService.loadRtuLife());
  }
  
  @SmartComment("通讯方式")
  public SmartView loadRtuComm() {
    return SmartView.SUCCESS(this.fesMngService.loadRtuComm());
  }
  
  @SmartComment("终端厂家")
  public SmartView loadRtuMenu() {
    return SmartView.SUCCESS(this.fesMngService.loadRtuMenu());
  }
  
  @SmartComment("根据GroupId查询chanInfo")
  public SmartView loadChanInfoByGroupId(Integer groupId) {
    return SmartView.SUCCESS(this.fesMngService.loadChanInfoByGroupId(groupId));
  }
  
  @SmartComment("保存更新rtu信息")
  public SmartView saveOrUpdateRtuInfo(RtuBean rtuData) {
    if (ParameterUtils.isEmptyOrNull(rtuData))
      return SmartView.ERROR("终端参数为空"); 
    System.out.println(rtuData);
    String workingDirectory = Constants.getString("dms.key.ftp.wrokdir", "/");
    String path = workingDirectory + "/" + rtuData.getSour1();
    File folder = new File(path + File.separator);
    if (!folder.exists())
      folder.mkdirs(); 
    return dbAccess(this.fesMngService.saveOrUpdateRtuInfo(rtuData));
  }
  
  public SmartView loadRtuInfoById(Integer rtuId) {
    if (ParameterUtils.isEmptyOrNull(rtuId))
      return SmartView.ERROR("终端Id为空"); 
    return SmartView.SUCCESS(this.fesMngService.loadRtuInfoById(rtuId));
  }
  
  public SmartView queryContainerInfo(String tableName, Long id) {
    if (ParameterUtils.isEmptyOrNull(tableName))
      return SmartView.ERROR("容器名为空"); 
    if (ParameterUtils.isEmptyOrNull(id))
      return SmartView.ERROR("容器Id为空"); 
    return SmartView.SUCCESS(this.fesMngService.queryContainerInfo(tableName, id));
  }
  
  public SmartView queryExtendChandata(Integer groupId, Integer chanId) {
    return SmartView.SUCCESS(this.fesMngService.queryExtendChandata(groupId, chanId));
  }
  
  public SmartView queryExtendGroupdata(Integer groupId, Integer chanId) {
    return SmartView.SUCCESS(this.fesMngService.queryExtendGroupdata(groupId, chanId));
  }
  
  @SmartComment("获取PMS所有终端信息")
  public SmartView loadPMSRtuInfo() {
    return null;
  }
  
  @SmartComment("删除通道")
  public SmartView deleteChanInfo(Integer chanId) {
    return dbAccess(this.fesMngService.deleteChanInfo(chanId));
  }
  
  @SmartComment("删除通道")
  public SmartView deleteRtuInfo(Integer rtuId) {
    return dbAccess(this.fesMngService.deleteRtuInfo(rtuId));
  }
  
  @SmartComment("pms终端信息")
  public SmartView queryPmsInfo(String desc, Integer type) {
    if (ParameterUtils.isEmptyOrNull(type))
      return SmartView.ERROR("终端类型不能为空"); 
    return SmartView.SUCCESS(this.fesMngService.queryPmsInfo(desc, type));
  }
  
  @SmartComment("新查询pms终端信息")
  public SmartView queryPmsRtuInfo(Integer type, String feederDesc, String rtuDesc) {
    if (ParameterUtils.isEmptyOrNull(type))
      return SmartView.ERROR("终端类型不能为空"); 
    return SmartView.SUCCESS();
  }
  
  @SmartComment("验证线路rdfId")
  public SmartView checkFeederRdfId(String desc, String tablename) {
    return SmartView.SUCCESS(this.fesMngService.checkFeederRdfId(desc, tablename));
  }
  
  @SmartComment("查询终端厂家")
  public SmartView queryManuFac(String desc) {
    return SmartView.SUCCESS(this.fesMngService.queryManuFac(desc));
  }
  
  @SmartComment("密钥文件")
  public SmartView saveCerFile(File file) {
    String type = file.getName().substring(file.getName().lastIndexOf(".") + 1);
    if (!type.equals("cer"))
      return SmartView.ERROR("文件类型格式应为cer"); 
    String filePath = Constants.getString("dms.file.path.cer", "home/smart/smartweb/cer");
    checkFolder(filePath, file.getName());
    try {
      FileCopyUtils.copy(file, new File(filePath + File.separator + file.getName()));
      String path = filePath + File.separator + file.getName();
    } catch (IOException e) {
      logger.warn(e);
      return SmartView.ERROR("文件上传失败");
    } 
    return SmartView.SUCCESS(file.getName());
  }
  
  @SmartComment("解析文件")
  public SmartView analysisCerFile(File file) {
    String type = file.getName().substring(file.getName().lastIndexOf(".") + 1);
    if (!type.equals("cer"))
      return SmartView.ERROR("文件类型格式应为cer"); 
    return SmartView.SUCCESS();
  }
  
  @SmartComment("重置密钥")
  public SmartView resetRtuKey(Integer rtuId, File file) {
    if (ParameterUtils.isEmptyOrNull(rtuId)) {
      logger.info("终端Id为空");
      return SmartView.ERROR("终端Id为空");
    } 
    if (file == null) {
      logger.debug("上传文件为空");
      return SmartView.ERROR("上传文件为空");
    } 
    return SmartView.SUCCESS(this.fesMngService.resetRtuKey(rtuId, file));
  }
  
  @SmartComment("保存rtu")
  public SmartView saveFesRtu(RtuBean rtuData, String cerContent) {
    if (ParameterUtils.isEmptyOrNull(rtuData)) {
      logger.info("rtu信息为空");
      return SmartView.ERROR("rtu信息为空");
    } 
    if (ParameterUtils.isEmptyOrNull(cerContent)) {
      logger.info("证书文件内容为空");
      return SmartView.ERROR("证书文件内容为空");
    } 
    return SmartView.SUCCESS(this.fesMngService.saveFesRtu(rtuData, cerContent));
  }
  
  public SmartView deletePoint(String modelName, int chanId, int rtuId, Map<String, Object> devList) {
    String ret = this.fesMngService.deleteImportRtu(modelName, chanId, rtuId, devList);
    if (ret.isEmpty())
      return SmartView.SUCCESS(); 
    return SmartView.ERROR(ret);
  }
  
  private File checkFolder(String path, String fileName) {
    File folder = new File(path + File.separator);
    if (!folder.exists())
      folder.mkdirs(); 
    if (fileName == null || fileName.isEmpty())
      return folder; 
    File file = new File(path + File.separator + fileName);
    if (file.exists())
      return file; 
    return null;
  }
  
  public SmartView encodeFile(File file) {
    if (file == null)
      return SmartView.ERROR("文件为空"); 
    String result = "";
    char[] ret = null;
    String type = file.getName().substring(file.getName().lastIndexOf(".") + 1);
    if (!type.equals("cer"))
      return SmartView.ERROR("文件类型格式应为cer"); 
    ByteArrayOutputStream bos = null;
    BufferedInputStream in = null;
    try {
      in = new BufferedInputStream(new FileInputStream(file));
      bos = new ByteArrayOutputStream((int)file.length());
      int buf_size = 1024;
      byte[] buffer = new byte[buf_size];
      int len = 0;
      try {
        while (-1 != (len = in.read(buffer, 0, buf_size)))
          bos.write(buffer, 0, len); 
        ret = encodeHex(buffer);
      } catch (IOException e) {
        e.printStackTrace();
      } 
    } catch (FileNotFoundException e) {
      e.printStackTrace();
    } 
    for (char ch : ret)
      result = result + ch; 
    result = file.getName() + "," + result;
    return SmartView.SUCCESS(result);
  }
  
  public static char[] encodeHex(byte[] data) {
    return encodeHex(data, true);
  }
  
  public static char[] encodeHex(byte[] data, boolean toLowerCase) {
    return encodeHex(data, toLowerCase ? DIGITS_LOWER : DIGITS_UPPER);
  }
  
  protected static char[] encodeHex(byte[] data, char[] toDigits) {
    int l = data.length;
    char[] out = new char[l << 1];
    int i = 0;
    for (int j = 0; i < l; i++) {
      out[j++] = toDigits[(0xF0 & data[i]) >>> 4];
      out[j++] = toDigits[0xF & data[i]];
    } 
    return out;
  }
  
  public static String encodeHexStr(byte[] data) {
    return encodeHexStr(data, true);
  }
  
  public static String encodeHexStr(byte[] data, boolean toLowerCase) {
    return encodeHexStr(data, toLowerCase ? DIGITS_LOWER : DIGITS_UPPER);
  }
  
  protected static String encodeHexStr(byte[] data, char[] toDigits) {
    if (data == null) {
      logger.error("this data is null.");
      return "";
    } 
    return new String(encodeHex(data, toDigits));
  }
  
  public static byte[] decodeHex(String data) {
    if (data == null) {
      logger.error("this data is null.");
      return new byte[0];
    } 
    return decodeHex(data.toCharArray());
  }
  
  public static byte[] decodeHex(char[] data) {
    int len = data.length;
    if ((len & 0x1) != 0)
      throw new RuntimeException("Odd number of characters."); 
    byte[] out = new byte[len >> 1];
    int i = 0;
    for (int j = 0; j < len; i++) {
      int f = toDigit(data[j], j) << 4;
      j++;
      f |= toDigit(data[j], j);
      j++;
      out[i] = (byte)(f & 0xFF);
    } 
    return out;
  }
  
  protected static int toDigit(char ch, int index) {
    int digit = Character.digit(ch, 16);
    if (digit == -1)
      throw new RuntimeException("Illegal hexadecimal character " + ch + " at index " + index); 
    return digit;
  }
  
  @SmartComment("获取规约组信息")
  public SmartView loadGroupInfo() {
    return SmartView.SUCCESS(this.fesMngService.loadGroupInfo());
  }
  
  @SmartComment("保存pms获取的rtu信息")
  public SmartView savaRtuPmsInfo(RtuPmsBean rtuPms) {
    if (ParameterUtils.isEmptyOrNull(rtuPms))
      return SmartView.ERROR("上传参数为空"); 
    return SmartView.SUCCESS(this.fesMngService.savaRtuPmsInfo(rtuPms));
  }
  
  @SmartComment("获取所有数据")
  public SmartView listInfo(RtuPmsParaVo queryPara) {
    QueryFilter queryFilter = new QueryFilter();
    try {
      queryFilter = queryPara.getQueryFilter(null, null);
    } catch (Exception e) {
      return SmartView.ERROR(e.getMessage());
    } 
    PagingBean page = this.fesMngService.queryRecords(queryFilter, queryPara);
    if (queryPara.isExport())
      try {
        List<HeaderConfig> headers = queryPara.getColumnList();
        ByteArrayOutputStream outputStream = new ByteArrayOutputStream();
        ExcelDataUtil.createExcelByMapList(page.getData(), headers).write(outputStream);
        return SmartView.FileView(outputStream, "前置管理统计.xls");
      } catch (Exception e) {
        e.printStackTrace();
        return SmartView.ERROR(I18n.message("error.excel.export", new Object[] { e.getMessage() }));
      }  
    return pageView(page);
  }
  
  @SmartComment("根据文件路径获取参数信息")
  public SmartView queryParaByPath(String filePath) {
    BufferedReader reader = null;
    Map<String, Object> map = new HashMap<>();
    String laststr = "";
    try {
      FileInputStream fileInputStream = new FileInputStream(filePath);
      InputStreamReader inputStreamReader = new InputStreamReader(fileInputStream, "UTF-8");
      reader = new BufferedReader(inputStreamReader);
      String tempString = null;
      while ((tempString = reader.readLine()) != null)
        laststr = laststr + tempString; 
      reader.close();
    } catch (IOException e1) {
      e1.printStackTrace();
    } 
    JSONArray jsonArray = JSONArray.fromObject(laststr);
    JSONObject jsonObject = JSONObject.fromObject(jsonArray.get(0).toString());
    RtuPmsBean alarmMsgBean = (RtuPmsBean)JSONObject.toBean(jsonObject, RtuPmsBean.class);
    return SmartView.SUCCESS(alarmMsgBean);
  }
  
  @SmartComment("保存终端证书文件")
  public SmartView saveFile(File file) {
    if (file != null) {
      this.WAVE_FILE_LOCATION = Constants.getString("dms.rtu.pms.files.folder", "D:/upload");
      this.WAVE_FILE_LOCATION += "/" + (new Date()).getTime();
      File f = checkFolder(file.getName());
      try {
        FileCopyUtils.copy(file, new File(this.WAVE_FILE_LOCATION + File.separator + file
              .getName()));
      } catch (IOException e) {
        logger.warn(e);
        return SmartView.ERROR("文件上传失败");
      } 
    } 
    return SmartView.SUCCESS(this.WAVE_FILE_LOCATION + File.separator + file.getName());
  }
  
  @SmartComment("上次密钥文件")
  public SmartView uploadKeyFile(String rtuId, File file) {
    if (ParameterUtils.isEmptyOrNull(rtuId))
      return SmartView.ERROR("终端Id为空"); 
    if (file == null)
      return SmartView.ERROR("上传文件为空"); 
    return SmartView.SUCCESS(this.fesMngService.uploadKeyFile(rtuId, file));
  }
  
  @SmartComment("检查图形，模型是否正确")
  public SmartView checkGraph(String desc, String tablename) {
    if (ParameterUtils.isEmptyOrNull(desc))
      return SmartView.ERROR("终端名称为空"); 
    if (ParameterUtils.isEmptyOrNull(tablename))
      return SmartView.ERROR("表名为空"); 
    return SmartView.SUCCESS(this.fesMngService.checkGraph(desc, tablename));
  }
  
  @SmartComment("一键生成通道、终端和终端建点")
  public SmartView importRtu(String modelName, RtuPmsBean rtuPms, Map<String, Object> devList, List<FesBean> extendChanData, List<FesBean> extendGroupData) {
    if (ParameterUtils.isEmptyOrNull(modelName))
      return SmartView.ERROR("点表模板为为空"); 
    if (ParameterUtils.isEmptyOrNull(rtuPms))
      return SmartView.ERROR("通道终端信息为空"); 
    if (ParameterUtils.isEmptyOrNull(devList))
      return SmartView.ERROR("设备点为空"); 
    return SmartView.SUCCESS(this.fesMngService.importRtu(modelName, rtuPms, devList, extendChanData, extendGroupData));
  }
  
  private File checkFolder(String fileName) {
    File folder = new File(this.WAVE_FILE_LOCATION + File.separator);
    if (!folder.exists())
      folder.mkdirs(); 
    if (fileName == null || fileName.isEmpty())
      return folder; 
    File file = new File(this.WAVE_FILE_LOCATION + File.separator + fileName);
    if (file.exists())
      return file; 
    return null;
  }
  
  @SmartComment("pms终端信息")
  public SmartView queryRtuPmsInfo(String feederDesc, String rtuDesc, Integer type) {
    if (ParameterUtils.isEmptyOrNull(type))
      return SmartView.ERROR("终端类型不能为空"); 
    return SmartView.SUCCESS(this.fesMngService.queryRtuPmsInfo(feederDesc, rtuDesc, type));
  }
  
  @SmartComment("")
  public SmartView judgeDevPoint(Map<String, Object> devList) {
    if (devList.size() == 0)
      return SmartView.ERROR("设备不能为空不能为空"); 
    Boolean ret = this.fesMngService.judgeDevPoint(devList);
    if (ret.booleanValue())
      return SmartView.SUCCESS(); 
    return SmartView.ERROR("设备已存在点，不能进行导点操作，请先删除后再导入");
  }
  
  @SmartComment("列出文件")
  public SmartView listFiles(String path) {
    File folder = new File(path);
    List<Map<String, Object>> list = new ArrayList<>();
    Map<String, Object> m = new HashMap<>();
    m.put("name", folder.getName());
    m.put("lastUpdateTime", DateUtil.format(new Date(folder.lastModified())));
    list.add(m);
    return SmartView.SUCCESS(list);
  }
  
  @SmartComment("")
  public SmartView checkChanRepreat(Integer chanId, String chanDesc, Integer groupId, List<FesBean> extendChanData) {
    if (ParameterUtils.isEmptyOrNull(chanId))
      return SmartView.SUCCESS(Boolean.valueOf(true)); 
    if (ParameterUtils.isEmptyOrNull(chanDesc))
      return SmartView.ERROR("请输入通道名称"); 
    if (ParameterUtils.isEmptyOrNull(groupId))
      return SmartView.ERROR("请选择规约组"); 
    if (ParameterUtils.isEmptyOrNull(extendChanData))
      return SmartView.ERROR("请选择通道参数"); 
    return SmartView.SUCCESS(this.fesMngService.checkChanRepreat(chanDesc, groupId, extendChanData));
  }
}
